server

package
v1.7.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 4, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type WebhookServer added in v1.4.4

type WebhookServer struct {
	Ready   bool
	Channel chan struct{}
}

func NewServer added in v1.4.4

func NewServer() *WebhookServer

func (*WebhookServer) Start added in v1.4.4

func (wh *WebhookServer) Start(config configuration.Config, p provider.Provider)

Init server initialization function The server will respond to the following endpoints: - / (GET): initialization, negotiates headers and returns the domain filter - /records (GET): returns the current records - /records (POST): applies the changes - /adjustendpoints (POST): executes the AdjustEndpoints method

func (*WebhookServer) StartHealth added in v1.4.4

func (wh *WebhookServer) StartHealth(config configuration.Config)

Jump to