Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type WebhookServer ¶ added in v1.4.4
type WebhookServer struct {
Ready bool
Channel chan struct{}
}
func NewServer ¶ added in v1.4.4
func NewServer() *WebhookServer
func (*WebhookServer) Start ¶ added in v1.4.4
func (wh *WebhookServer) Start(config configuration.Config, p provider.Provider)
Init server initialization function The server will respond to the following endpoints: - / (GET): initialization, negotiates headers and returns the domain filter - /records (GET): returns the current records - /records (POST): applies the changes - /adjustendpoints (POST): executes the AdjustEndpoints method
func (*WebhookServer) StartHealth ¶ added in v1.4.4
func (wh *WebhookServer) StartHealth(config configuration.Config)
Click to show internal directories.
Click to hide internal directories.